==> types-vue-1.0.10.tgz: package/lib/vuex/Action.js <==
import { createVuexDecorator } from "./utils";
function checkOptionsCommit(options, context, value) {
    if (options && options.commit) {
        context.commit(options.commit, value);
    }
}
function createActionFunction(key, value, options) {
    var action = function (context, payload) {
        try {
            var arrPayload = payload;
            var parameters = options.useContext ? [context].concat(arrPayload) : arrPayload;
            var callResult_1 = value.call.apply(value, [context].concat(parameters));
            if (Promise.resolve(callResult_1) !== callResult_1) {
                checkOptionsCommit(options, context, callResult_1);
                return callResult_1;
            }
            return new Promise(function (resolve, reject) {
                callResult_1.then(function (result) {
                    checkOptionsCommit(options, context, result);
                    resolve(result);
                }, function (error) {
                    reject(error);
                });
            });
        }
        catch (ex) {
            console.error('Could not perform action ' + key.toString());
        }
    };
    return action;
}
export function Action(options) {
    if (options === void 0) { options = {}; }
    return createVuexDecorator(function (componentOptions, k, description) {
        if (typeof componentOptions.actions !== 'object') {
            componentOptions.actions = Object.create(null);
        }
        componentOptions.actions[k] = createActionFunction(k, description.value, options);
    });
}

==> types-vue-1.0.11.tgz: package/lib/vuex/Action.js <==
import { createVuexDecorator } from "./utils";
function checkOptionsCommit(options, context, value) {
    if (options && options.commit) {
        context.commit(options.commit, value);
    }
}
function createActionFunction(key, value, options) {
    var action = function (context, payload) {
        try {
            var arrPayload = payload;
            var parameters = options.useContext ? [context].concat(arrPayload) : arrPayload;
            var callResult_1 = value.call.apply(value, [context].concat(parameters));
            if (Promise.resolve(callResult_1) !== callResult_1) { // it is not a promise
                checkOptionsCommit(options, context, callResult_1);
                return callResult_1;
            }
            return new Promise(function (resolve, reject) {
                callResult_1.then(function (result) {
                    checkOptionsCommit(options, context, result);
                    resolve(result);
                }, function (error) {
                    reject(error);
                });
            });
        }
        catch (ex) {
            console.error('Could not perform action ' + key.toString());
        }
    };
    return action;
}
export function Action(options) {
    if (options === void 0) { options = {}; }
    return createVuexDecorator(function (componentOptions, k, description) {
        if (typeof componentOptions.actions !== 'object') {
            componentOptions.actions = Object.create(null);
        }
        componentOptions.actions[k] = createActionFunction(k, description.value, options);
    });
}
